Changelog — django_openS3 0.1.0 documentation

### Navigation

- index
- django_openS3 0.1.0 documentation »

# Changelog

## 0.1.0

- Create a django storage that wraps openS3.

### Table Of Contents

- Changelog
  - 0.1.0

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- django_openS3 0.1.0 documentation »

© Copyright 2015, Paul Logston. Created using Sphinx 1.2.3.